define(
//begin v1.x content
({
	"findLabel": "Cerca:",
	"findTooltip": "Especifiqueu el text que voleu trobar",
	"replaceLabel": "Substitueix per:",
	"replaceTooltip": "Especifiqueu el text amb què el voleu substituir",
	"findReplace": "Cerca i substitueix",
	"matchCase": "Coincidència de majúscules i minúscules",
	"matchCaseTooltip": "Coincidència de majúscules i minúscules",
	"backwards": "Cap enrere",
	"backwardsTooltip": "Cerca text cap enrere",
	"replaceAllButton": "Substitueix tot",
	"replaceAllButtonTooltip": "Substitueix tot el text",
	"findButton": "Cerca",
	"findButtonTooltip": "Troba el text",
	"replaceButton": "Substitueix",
	"replaceButtonTooltip": "Substitueix el text",
	"replaceDialogText": "S'han substituït ${0} aparicions.",
	"eofDialogText": "Darrera aparició ${0}",
	"eofDialogTextFind": "trobat",
	"eofDialogTextReplace": "substituït"
})

//end v1.x content
);
